<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: MaintenanceCommon.php 4130 2006-01-26 18:05:33Z andrew@m3.net $
*/

require_once MAX_PATH . '/lib/max/Dal/Common.php';
require_once MAX_PATH . '/lib/max/Maintenance/OperationInterval.php';

/**
 * The non-DB specific base Data Access Layer (DAL) class that provides
 * functionality that is common to all of the specific Maintenance DALs.
 * These DALs are the Maintenance and Forecasting DALs.
 *
 * @package    MaxDal
 * @author     Andrew Hill <andrew@m3.net>
 */
class MAX_Dal_Maintenance_Common extends MAX_Dal_Common
{

    /**
     * The class constructor method.
     */
    function MAX_Dal_Maintenance_Common()
    {
        parent::MAX_Dal_Common();
    }

    /**
     * A private method to manage creation of the Maintenance class.
     *
     * @access private
     * @return mixed An instance of the Maintenance class.
     */
    function &_getMaintenance()
    {
        $oServiceLocator = &ServiceLocator::instance();
        $maintenance = $oServiceLocator->get('Maintenance');
        if (!$maintenance) {
            $maintenance = &new Maintenance();
        }
        return $maintenance;
    }

    /**
     * A method to store the last time that a Maintenance or Forecasting script
     * ran.
     *
     * @param Date $start The time that the script run started.
     * @param Date $end The time that the script run ended.
     * @param Date $updateTo The end of the last operation interval ID that
     *                       has been updated.
     * @param string $tableName The name of Maintenance or Forecasting log table
     */
    function setScriptLastRunInfo($start, $end, $updateTo, $tableName)
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        $duration = new Date_Span();
        $oStartDateCopy = &new Date($start); // Clone for Date_Span::setFromDateDiff bug in PHP5
        $oEndDateCopy   = &new Date($end);   // Clone for Date_Span::setFromDateDiff bug in PHP5
        $duration->setFromDateDiff($oStartDateCopy, $oEndDateCopy);
        $query = "
            INSERT INTO
                {$conf['table']['prefix']}{$conf['table'][$tableName]}
                (
                    start_run,
                    end_run,
                    operation_interval,
                    duration,
                    updated_to
                )
            VALUES
                (
                    '".$start->format('%Y-%m-%d %H:%M:%S')."',
                    '".$end->format('%Y-%m-%d %H:%M:%S')."',
                    {$conf['maintenance']['operationInterval']},
                    ".$duration->toSeconds().",
                    '".$updateTo->format('%Y-%m-%d %H:%M:%S')."'
                )";
        MAX::debug("Logging the script run information into $tableName", PEAR_LOG_DEBUG);
        $result = $this->dbh->query($query);
        if(DB::isError($result)) {
            return false;
        } else {
            return $result;
        }
    }

    /**
     * A method to return the time that a Maintenance or Forecasting script
     * was last run, and the operation interval that was in use at the time.
     *
     * @param string $tableName The name of script log table
     * @param array  $additionalFields Any additional fields
     * @return array An array containing the time that represents the last time
     *               maintenance {type} was last run (started). Returns an
     *               array of 2 NULLs if maintenance has never been run.
     */
    function getScriptLastRunInfo($tableName, $additionalFields = array(), $orderBy = 'start_run')
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        $this->queryBuilder->reset();
        $this->queryBuilder->setTable($conf['table']['prefix'] . $conf['table'][$tableName]);
        $this->queryBuilder->setSelect('updated_to');
        foreach ($additionalFields as $field) {
            $this->queryBuilder->addSelect($field);
        }
        $this->queryBuilder->setOrder($orderBy, true);
        $this->queryBuilder->setLimit(0, 1);
        MAX::debug('Obtaining the maintenance run information from table: '.$tableName, PEAR_LOG_DEBUG);
        $rows = $this->queryBuilder->getAll();
        return (count($rows) == 1) ? $rows[0] : false;
    }

    /**
     * Obtains a database-level lock for the Maintenance Priority Engine process.
     *
     * @param string $lockName  Lock name
     * @return boolean True if lock was obtained, false otherwise.
     */
    function obtainLock($lockName)
    {
        $query = "SELECT GET_LOCK('$lockName', 1) AS 'lock'";
        $result = $this->dbh->query($query);
        $row = $result->fetchRow();
        if ($row['lock'] == 1) {
            // Lock obtained successfully
            return true;
        }
        return false;
    }

    /**
     * Releases the database-level lock for the Maintenance Priority Engine process.
     *
     * @param string $lockName  Lock name
     * @return mixed True if lock was released, a PEAR Error otherwise.
     */
    function releaseLock($lockName)
    {
        $query = "SELECT RELEASE_LOCK('$lockName')";
        return $this->dbh->query($query);
    }

    /**
     * Returns an array of delivery limitation hashes for ads or channels.
     *
        Array
        (
            [0] => Array
                (
                    [$primaryKey] => 3
                    [logical] => and
                    [type] => date
                    [comparison] => !=
                    [data] => 2005-5-25
                    [executionorder] => 0
                )

            [1] => Array
         ...
     *
     * @param array $fields
     * @param array $wheres
     * @param array $joins
     * @param array $orderBys
     * @param string $primaryKey  Either bannerid or channelid
     * @param string $tableName   Either acls or acls_channel
     * @return array
     */
    function getDeliveryLimitations($fields = array(), $wheres = array(), $joins = array(), $orderBys = array(), $tableName, $primaryKey)
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        $table = $conf['table']['prefix'] . $tableName;
        $this->queryBuilder->reset();
        $this->queryBuilder->setTable($table);
        $this->queryBuilder->setSelect("$table.$primaryKey");
        $this->queryBuilder->addSelect("$table.logical");
        $this->queryBuilder->addSelect("$table.type");
        $this->queryBuilder->addSelect("$table.comparison");
        $this->queryBuilder->addSelect("$table.data");
        $this->queryBuilder->addSelect("$table.executionorder");
        // Where conditions
        foreach ($wheres as $where) {
            list($constraint, $operator) = $where;
            $this->queryBuilder->addWhere($constraint, $operator);
        }
        // Joins
        foreach ($joins as $join) {
            list($table, $joinCond) = $join;
            $this->queryBuilder->addJoin($table, $joinCond);
        }
        return $this->queryBuilder->getAll();
    }

}