<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: AllocateZoneImpressions.php 3416 2005-06-30 14:40:49Z andrew $
*/

require_once MAX_PATH . '/lib/max/other/lib-limitations.inc.php';

/**
 * A class to create channel limitations
 *
 * @package    MaxMaintenance
 * @subpackage Forecasting
 * @author     Radek Maciaszek <radek@m3.net>
 */
class MAX_Maintenance_Forecasting_Channel_Limitations
{
    /**
     * Containt all available limitations
     * @var array
     */
    var $limitations = array(
        'clientip'     => 'phpAds_aclCheckClientIP',
        'browser'      => 'phpAds_aclCheckUseragent',
        'os'           => 'phpAds_aclCheckUseragent',
        'useragent'    => 'phpAds_aclCheckUseragent',
        'language'     => 'phpAds_aclCheckLanguage',
        'country_code' => 'phpAds_aclCheckCountryCode',
        'country_name' => 'phpAds_aclCheckCountryName',
        'region'       => 'phpAds_aclCheckRegion',
        'city'         => 'phpAds_aclCheckCity',
        'postal_code'  => 'phpAds_aclCheckPostalCode',
        'latitude'     => 'phpAds_aclCheckPostalLatitude',
        'longitude'    => 'phpAds_aclCheckPostalLongitude',
        'dma_code'     => 'phpAds_aclCheckPostalDmaCode',
        'area_code'    => 'phpAds_aclCheckPostalAreaCode',
        'organisation' => 'phpAds_aclCheckPostalOrganisation',
        'netspeed'     => 'phpAds_aclCheckPostalNetspeed',
        'continent'    => 'phpAds_aclCheckContinent',
        'weekday'      => 'phpAds_aclCheckWeekday',
        'domain'       => 'phpAds_aclCheckDomain',
        'source'       => 'phpAds_aclCheckSource',
        'time'         => 'phpAds_aclCheckTime',
        'date'         => 'phpAds_aclCheckDate',
        'referer'      => 'phpAds_aclCheckReferer',
    );
    
    /**
     * Check if sql limitation exists
     *
     * @param string $limitationName  Limitation type
     *
     * @return boolean  True if exists else false
     */
    function isSqlLimitationExists($limitationName)
    {
        $methodName = 'getSqlLimitationFor_'.ucfirst($limitationName);
        return method_exists($this, $methodName);
    }

    /**
     * Get SQL limitations for limitation type
     *
     * @param string $limitationName  Limitation type
     * @param string $data            Additional data
     * @param string $ad              Is equal (either == or !=)
     *
     * @return string - SQL limitation or null if doesn't exists
     */
    function getSqlLimitation($limitationName, $data, $comparison)
    {
        $methodName = 'getSqlLimitationFor_'.$limitationName;
        if(method_exists($this, $methodName)) {
            $check = $this->checkData($data, $comparison);
            if($check !== null) {
                return $check;
            }
            if($comparison == '==') {
                $comparison = '=';
            }
            return call_user_func(array($this, $methodName), $data, $comparison);
        } else {
            return null;
        }
    }

    /**
     * Get SQL limitations for limitation type
     *
     * @param string $limitationName  Limitation type
     * @param string $data            Additional data
     * @param string $ad              Is equal (either == or !=)
     *
     * @return string - SQL limitation or null if doesn't exists
     */
    function getPhpLimitation($limitationName, $data, $comparison, $source = null)
    {
        if(!isset($this->limitations[$limitationName])) {
            return null;
        }
        $functionName = $this->limitations[$limitationName];
        if(function_exists($functionName)) {
            return "$functionName('".$data."', '".$comparison."', $"."source)";
        }
        return null;
    }
    
    /**
     * Return country code (in ISO-3166) for country name
     *
     * @param string $countryName
     * @return mixed  Country code or false if such code doesn't exists
     */
    function getCountryCodeForName($countryName)
    {
        static $countries;
        
        if(!isset($countries)) {
            include MAX_PATH . '/lib/max/resources/res-iso3166.inc.php';
            if(!isset($phpAds_ISO3166)) {
                return false;
            }
        }
        $countryName = strtolower($countryName);
        foreach ($phpAds_ISO3166 as $countryCode => $country) {
            if($countryName == strtolower($country)) {
                return strtolower($countryCode);
            }
        }
        return false;
    }
    
    /**
     * Check if limitation is always true of false for empty or equal * data
     *
     * @param string $data  Limitations data (taken from acls table)
     * @param string $eq    Comparison (either '==' or '!=', sometimes '<', '>=', etc)
     * @return mixed        1/0 or null
     */
    function checkData($data, $eq, $checkIfEmpty = true)
    {
        if($checkIfEmpty && empty($data)) {
            return 1;
        }
        if($data == '*') {
            if ($eq == '==') {
                return 1;
            } else {
                return 0;
            }
        }
        
        return null;
    }

    
    // --------------------- SQL limitations ------------------------
    
    /**
     * Implements method for country_code
     */
    function getSqlLimitationFor_country_code($data, $eq)
    {
        if(empty($data)) {
            return ($eq != '=');
        }
        $comparison = 'IN';
        if($eq != '=') {
            $comparison = 'NOT '.$comparison;
        }
        
        $countriesCodes = explode(',', $data);
        foreach ($countriesCodes as $key => $value) {
            $countriesCodes[$key] = "'".$value."'";
        }
        
        $sql = "country $comparison (".implode(',', $countriesCodes).")";
        return $sql;
    }

    /**
     * Implements method for checking country name
     */
    function getSqlLimitationFor_country_name($data, $eq)
    {
        $countriesNames = explode(',', $data);
        $countriesCodes = array();
        foreach($countriesNames as $countryName) {
            $countryCode = $this->getCountryCodeForName($countryName);
            if(!empty($countryCode)) {
                $countriesCodes[] = $countryCode;
            }
        }
        if(empty($countriesCodes) && !empty($countriesNames)) {
            if($eq == '=') {
                return false; // No record will much it
            } else {
                return true; // All records will much it
            }
        }
        
        return $this->getSqlLimitationFor_country_code(implode(',', $countriesCodes), $eq);
    }

    /**
     * Implements method for checking source
     */
    function getSqlLimitationFor_source($data, $eq)
    {
        /*
        $comparison = ($eq == '=') ? '' : 'NOT ';
        
        $pattern = str_replace('*', '.*', str_replace('.', '\.', str_replace('(', '[\(]', str_replace(')', '\)', $data))));
        $sql = $comparison . "(channel = '$data' OR channel REGEXP '$pattern')";
        */
        // Use LIKE instead of REGEXP
        $comparison = ($eq == '=') ? 'LIKE' : 'NOT LIKE';
        $pattern = str_replace('*', '%', $data);
        
        $sql = "channel $comparison '$pattern'";
        
        return $sql;
    }

    /**
     * Implements method for checking client ip
     */
    function getSqlLimitationFor_clientip($data, $eq)
    {
        // replace * with %
        $data = str_replace('*', '%', $data);
        
        $comparison = 'LIKE';
        if($eq != '=') {
            $comparison = 'NOT '.$comparison;
        }
        $sql = "ip_address $comparison '$data'";
        return $sql;
    }

    /**
     * Implements method for checking week day
     */
    function getSqlLimitationFor_weekday($data, $eq)
    {
        $maxDaysOfWeek = explode(',', $data);
        // Add 1 to every day (In MMM 0 == sunday, in MySQL 1 == sunday)
        $mysqlDaysOfWeek = array();
        foreach($maxDaysOfWeek as $dayOfWeek) {
            $mysqlDaysOfWeek[] = $dayOfWeek + 1;
        }
        
        $comparison = 'IN';
        if($eq != '=') {
            $comparison = 'NOT '.$comparison;
        }
        
        $sql = "DAYOFWEEK(date_time) $comparison (".implode(',', $mysqlDaysOfWeek).")";
        return $sql;
    }

    /**
     * Implements method for checking user agent
     */
    function getSqlLimitationFor_browser($data, $eq)
    {
        $comparison = ($eq == '=') ? '' : '!';
        $pattern = str_replace('.', '\.', str_replace('(', '\(', str_replace(')', '\)', $data)));
        $sql = $comparison . "(user_agent REGEXP '$pattern')";
        return $sql;
    }

    /**
     * Implements method for checking user agent
     */
    function getSqlLimitationFor_useragent($data, $eq)
    {
        return $this->getSqlLimitationFor_browser($data, $eq);
    }

    /**
     * Implements method for checking operating system
     */
    function getSqlLimitationFor_os($data, $eq)
    {
        return $this->getSqlLimitationFor_browser($data, $eq);
    }

    /**
     * Implements method for checking domain
     */
    function getSqlLimitationFor_domain($data, $eq)
    {
        $rightLength = strlen($data);
        $sql = "RIGHT(host_name, $rightLength) $eq '$data'";
        return $sql;
    }

    /**
     * Implements method for checking language
     */
    function getSqlLimitationFor_language($data, $eq)
    {
        $comparison = ($eq == '=') ? '' : '!';
        $pattern = str_replace('.', '\.', str_replace('(', '\(', str_replace(')', '\)', $data)));
        $sql = $comparison . "(language REGEXP '^($pattern)')";
        return $sql;
    }
    
    /**
     * Implements method for checking time
     */
    function getSqlLimitationFor_time($data, $eq)
    {
        $comparison = ($eq == '=') ? 'IN' : 'NOT IN';
        $sql = "hour(date_time) $comparison ($data)";
        return $sql;
    }
    
    /**
     * Implements method for checking date
     */
    function getSqlLimitationFor_date($data, $eq)
    {
        if ($data == '00000000') {
            return true;
        }
        $sql = "DATE_FORMAT(date_time, '%Y%m%d') $eq '$data'";
        return $sql;
    }

    /**
     * Implements method for checking date
     */
    function getSqlLimitationFor_referer($data, $eq)
    {
        $comparison = 'LIKE';
        if($eq != '=') {
            $comparison = 'NOT '.$comparison;
        }
        
        $schemeSql = '';
        $pos = strpos($data, 'http');
        if($pos === 0) {
            $pos = strpos($data, 'https://');
            $scheme = ($pos === 0) ? 1 : 0;
            if($pos === 0) {
                $data = substr($data, strlen('https://'), strlen($data));
            } else {
                $data = substr($data, strlen('http://'), strlen($data));
            }
            
            $schemeSql = "https = $scheme AND";
        }
        
        $data = strtolower($data);
        $sql = "($schemeSql LOWER(CONCAT(domain,page)) $comparison '%$data%')";
        return $sql;
    }
    
    /**
     * Common method for all the geoip limitations
     *
     * @param string $columnName  GeoIP column name (in raw data tables)
     */
    function getSqlLimitationForGeoIP($columnName, $data, $eq)
    {
        $comparison = ($eq == '=') ? 'IN' : 'NOT IN';
        $sql = "$columnName $comparison ($data)";
        return $sql;
    }
    
    
    // Geotargeting limitations
    
    function getSqlLimitationFor_region($data, $eq)
    {
        return $this->getSqlLimitationForGeoIP('geo_region', $data, $eq);
    }
    
    function getSqlLimitationFor_city($data, $eq)
    {
        return $this->getSqlLimitationForGeoIP('geo_city', $data, $eq);
    }
    
    function getSqlLimitationFor_postal_code($data, $eq)
    {
        return $this->getSqlLimitationForGeoIP('geo_postal_code', $data, $eq);
    }
    
    function getSqlLimitationFor_latitude($data, $eq)
    {
        return $this->getSqlLimitationForGeoIP('geo_latitude', $data, $eq);
    }
    
    function getSqlLimitationFor_longitude($data, $eq)
    {
        return $this->getSqlLimitationForGeoIP('geo_longitude', $data, $eq);
    }
    
    function getSqlLimitationFor_dma_code($data, $eq)
    {
        return $this->getSqlLimitationForGeoIP('geo_dma_code', $data, $eq);
    }
    
    function getSqlLimitationFor_area_code($data, $eq)
    {
        return $this->getSqlLimitationForGeoIP('geo_area_code', $data, $eq);
    }
    
    function getSqlLimitationFor_organisation($data, $eq)
    {
        return $this->getSqlLimitationForGeoIP('geo_organisation', $data, $eq);
    }
    
    function getSqlLimitationFor_netspeed($data, $eq)
    {
        return $this->getSqlLimitationForGeoIP('geo_netspeed', $data, $eq);
    }
    
    function getSqlLimitationFor_continent($data, $eq)
    {
        return $this->getSqlLimitationForGeoIP('geo_continent', $data, $eq);
    }
}

?>