<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Task.php 4136 2006-01-27 16:24:36Z andrew@m3.net $
*/

require_once MAX_PATH . '/lib/max/Dal/Maintenance.php';
require_once MAX_PATH . '/lib/max/Maintenance/OperationInterval.php';
require_once MAX_PATH . '/lib/max/Table/Priority.php';
require_once MAX_PATH . '/lib/core/ServiceLocator.php';

/**
 * A parent class for Maintenance Priority tasks.
 *
 * @package    MaxMaintenance
 * @subpackage Priority
 * @author     Demian Turner <demian@m3.net>
 */
class MAX_Maintenance_Priority_AdServer_Task
{

    /**
     * object of type MAX_Dal_Maintenance
     * @var object
     */
    var $oDal;

    /**
     * object of type OperationInterval
     * @var object
     */
    var $oOperationInt;

    function MAX_Maintenance_Priority_AdServer_Task()
    {
        $this->oDal = &$this->_getDal();
        $this->oOperationInt = &$this->_getOperationIntUtils();
    }

    /**
     * The main method that is called in children classes to get them
     * to perform their main task(s).
     *
     * @abstract
     */
    function run()
    {
        return;
    }

    /**
     * Method to create/register/return the Maintenance Data Access Layer.
     *
     * @access private
     */
    function &_getDal()
    {
        $oServiceLocator = &ServiceLocator::instance();
        $oDal = &$oServiceLocator->get('MAX_Dal_Maintenance');
        if (!$oDal) {
            $oDal = &MAX_Dal_Maintenance::singleton();
            $oServiceLocator->register('MAX_Dal_Maintenance', $oDal);
        }
        return $oDal;
    }

    /**
     * Method to create/register/return the Maintenance Priority table class.
     *
     * @access private
     */
    function &_getMaxTablePriorityObj()
    {
        $dbType = strtolower($GLOBALS['_MAX']['CONF']['database']['type']);
        $oServiceLocator = &ServiceLocator::instance();
        $oTable = $oServiceLocator->get('MAX_Table_Priority');
        if (!$oTable) {
            $oTable = &MAX_Table_Priority::singleton($dbType);
            $oServiceLocator->register('MAX_Table_Priority', $oTable);
        }
        return $oTable;
    }

    /**
     * Method to register an OperationInterval class.
     *
     * @access private
     */
    function &_getOperationIntUtils()
    {
        return OperationInterval::singleton();
    }

}

?>
