<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Empty.php 4130 2006-01-26 18:05:33Z andrew@m3.net $
*/

require_once 'Date.php';

/**
 * A class that is used to store and manipulate individual delivery limitations
 * for ads, where the delivery limitation is NOT of the Time:Date, Time:Day or
 * Time:Hour type.
 *
 * @package    MaxMaintenance
 * @subpackage Priority
 * @author     Andrew Hill <andrew@m3.net>
 * @author     James Floyd <james@m3.net>
 */
class MAX_Maintenance_Priority_DeliveryLimitation_Empty extends MAX_Maintenance_Priority_DeliveryLimitation
{

    /**
     * Constructor method.
     *
     * @param array $aDeliveryLimitations An array of delivery limitation properties
     *                                    associated with an ad. For example:
     *                                        array(
     *                                            [ad_id]             => 1
     *                                            [logical]           => and
     *                                            [type]              => Time:Hour
     *                                            [comparison]        => ==
     *                                            [data]              => 1,7,18,23
     *                                            [executionorder]    => 1
     *                                        )
     * @return MAX_Maintenance_Priority_DeliveryLimitation_Empty
     */
    function MAX_Maintenance_Priority_DeliveryLimitation_Empty($aDeliveryLimitations)
    {
        parent::MAX_Maintenance_Priority_DeliveryLimitation($aDeliveryLimitations);
    }

    /**
     * A method to convert delivery limitations into negative form (i.e. when
     * NOT to deliver ad, as opposed to when to deliver).
     *
     * @return void
     */
    function calculateNonDeliveryDeliveryLimitation()
    {
        // Nothing to change in this class.
        return;
    }

    /**
     * A method to return the number of minutes each delivery limitation covers.
     *
     * @return integer
     */
    function minutesPerTimePeriod()
    {
        // It is not appropriate to talk about the number of minutes covered
        // by the ACLs represented by this class, so return zero
        return 0;
    }

    /**
     * A method to determine if the delivery limitation stored will prevent an
     * ad from delivering or not, given a time/date.
     *
     * @abstract
     * @param object $oDate PEAR:Date, represeting the time/date to test if the ACL would
     *                      block delivery at that point in time.
     * @return boolean True  => The ad will deliver
     *                 False => The ad will not deliver
     */
    function testInterval($oDate) {
        // The ACLs represented by this class do not block delivery, so return true
        return true;
    }

}

?>
