<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Hour.php 4130 2006-01-26 18:05:33Z andrew@m3.net $
*/

require_once 'Date.php';

/**
 * A class that is used to store and manipulate individual delivery limitations
 * for ads, where the delivery limitation is of the Time:Hour type.
 *
 * @package    MaxMaintenance
 * @subpackage Priority
 * @author     Andrew Hill <andrew@m3.net>
 * @author     James Floyd <james@m3.net>
 */
class MAX_Maintenance_Priority_DeliveryLimitation_Hour extends MAX_Maintenance_Priority_DeliveryLimitation
{

    /**
     * Constructor method.
     *
     * @param array $aDeliveryLimitations An array of delivery limitation properties
     *                                    associated with an ad. For example:
     *                                        array(
     *                                            [ad_id]             => 1
     *                                            [logical]           => and
     *                                            [type]              => Time:Hour
     *                                            [comparison]        => ==
     *                                            [data]              => 1,7,18,23
     *                                            [executionorder]    => 1
     *                                        )
     * @return MAX_Maintenance_Priority_DeliveryLimitation_Hour
     */
    function MAX_Maintenance_Priority_DeliveryLimitation_Hour($aDeliveryLimitations)
    {
        parent::MAX_Maintenance_Priority_DeliveryLimitation($aDeliveryLimitations);
    }

    /**
     * A method to convert delivery limitations into negative form (i.e. when
     * NOT to deliver ad, as opposed to when to deliver).
     *
     * Time:Hour delivery limitations can only be stored in terms of ==, or !=,
     * so conversion is only required if the comparison type stored is ==.
     *
     * @return void
     */
    function calculateNonDeliveryDeliveryLimitation() {
        if ($this->comparison == '==') {
            // Alternate the hour values stored
            $hours = range(0,23);
            foreach ($this->data as $val) {
                $key = array_search($val, $hours);
                unset($hours[$key]);
            }
            $this->data = $hours;
            // Convert the comparison type
            $this->comparison = $this->_getNonDeliveryOperator($this->comparison);
        }
    }

    /**
     * A method to return the number of minutes each delivery limitation covers.
     *
     * @return integer
     */
    function minutesPerTimePeriod() {
        // Return the minutes in an hour
        return 60;
    }

    /**
     * A method to determine if the delivery limitation stored will prevent an
     * ad from delivering or not, given a time/date.
     *
     * @abstract
     * @param object $oDate PEAR:Date, represeting the time/date to test if the ACL would
     *                      block delivery at that point in time.
     * @return boolean True  => The ad will deliver
     *                 False => The ad will not deliver
     */
    function testInterval($oDate)
    {
        return (in_array($oDate->getHour(), $this->data)) ? 1 : 0;
    }

}

?>
