<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: PriorityAdServerGetRequiredAdImpressionsType1.mtp.test.php 4130 2006-01-26 18:05:33Z andrew@m3.net $
*/

require_once MAX_PATH . '/lib/core/ServiceLocator.php';
require_once MAX_PATH . '/lib/max/Maintenance/Priority/AdServer/tasks/GetRequiredAdImpressionsType1.php';
require_once 'Date.php';

/**
 * A class for testing the GetRequiredAdImpressionsType1 class.
 *
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@m3.net>
 * @author     James Floyd <james@m3.net>
 */
class TestOfPriorityAdserverGetRequiredAdImpressionsType1 extends UnitTestCase
{

    /**
     * The constructor method.
     */
    function TestOfPriorityAdserverGetRequiredAdImpressionsType1()
    {
        $this->UnitTestCase();
        Mock::generate('MAX_Dal_Maintenance');
        Mock::generate('MAX_Table_Priority');
    }

    /**
     * A private method for the test class that creates an instance
     * of the mocked DAL class (MAX_Dal_Maintenance), the mocked
     * table creation class (MAX_Table_Priority), registeres the
     * mocked classes in the ServiceLocator, and then returns an
     * instance of the GetRequiredAdImpressionsType1 class to use
     * in testing.
     *
     * @access private
     * @return GetRequiredAdImpressionsType1
     */
    function &_getCurrentTask()
    {
        $oDal   = &new MockMAX_Dal_Maintenance($this);
        $oTable = &new MockMAX_Table_Priority($this);
        $oServiceLocator = &ServiceLocator::instance();
        $oServiceLocator->register('MAX_Dal_Maintenance', $oDal);
        $oServiceLocator->register('MAX_Table_Priority',  $oTable);
        return new GetRequiredAdImpressionsType1();
    }

    /**
     * A method to test the _getDate() method.
     *
     * Requirements:
     * Test 1: Test with no date in the ServiceLocator, and ensure that the
     *         current date/time is returned.
     * Test 2: Test with a date in the ServiceLocator, and ensure that the
     *         correct date/time is returned.
     * Test 3: Test with a date passed in as a parameter, and ensure that the
     *         correct date/time is returned.
     */
    function test_getDate()
    {
        $oGetRequiredImpressionsType1 = &$this->_getCurrentTask();

        // Test 1
        $oServiceLocator = &ServiceLocator::instance();
        $oServiceLocator->remove('now');
        $oDate1 = $oGetRequiredImpressionsType1->_getDate();
        $oDate2 = $oServiceLocator->get('now');
        $this->assertTrue(is_a($oDate1, 'Date'));
        $this->assertTrue(is_a($oDate2, 'Date'));
        $this->assertTrue($oDate1->equals($oDate2));

        // Test 2
        $oDate1 = &new Date();
        $oServiceLocator->register('now', $oDate1);
        $oDate2 = $oGetRequiredImpressionsType1->_getDate();
        $this->assertTrue(is_a($oDate2, 'Date'));
        $this->assertTrue($oDate1->equals($oDate2));

        // Test 3
        $oDate1 = &new Date('2005-12-08 13:55:00');
        $oDate2 = $oGetRequiredImpressionsType1->_getDate($oDate1->format('%Y-%m-%d %H:%M:%S'));
        $this->assertTrue(is_a($oDate2, 'Date'));
        $this->assertTrue($oDate1->equals($oDate2));
    }

    /**
     * A method to test the getAllPlacements() method.
     *
     * For each test, sets the return value of the mocked DAL object's
     * getPlacements() method, and then ensure that the returned value
     * from a call to the getAllPlacements() method is correct.
     *
     * Requirements:
     * Test 1: Tests when no data is returned from the DAL.
     * Test 2: Tests where data is returned from the DAL.
     */
    function testGetAllPlacements()
    {
        $oGetRequiredImpressionsType1 = &$this->_getCurrentTask();

        // Test 1
        $oGetRequiredImpressionsType1->oDal->setReturnValueAt(
            0,
            'getPlacements',
            array()
        );
        $oResult = $oGetRequiredImpressionsType1->getAllPlacements();
        $this->assertTrue(is_array($oResult));
        $this->assertEqual(count($oResult), 0);

        // Test 2
        $oGetRequiredImpressionsType1->oDal->setReturnValueAt(
            1,
            'getPlacements',
            array(
                array(
                    'campaignid'        => 1,
                    'expire'            => '2005-12-08 13:55:00',
                    'views'             => 10,
                    'clicks'            => 20,
                    'conversions'       => 30,
                    'target_impression' => 5,
                    'target_click'      => 6,
                    'target_conversion' => 7,
                    'priority'          => 3
                ),
                array(
                    'campaignid'        => 2,
                    'expire'            => '2005-12-08 13:55:01',
                    'views'             => 11,
                    'clicks'            => 21,
                    'conversions'       => 31,
                    'target_impression' => 6,
                    'target_click'      => 7,
                    'target_conversion' => 8,
                    'priority'          => 4
                )
            )
        );
        $oResult = $oGetRequiredImpressionsType1->getAllPlacements();
        $this->assertTrue(is_array($oResult));
        $this->assertEqual(count($oResult), 2);
        $this->assertTrue(is_a($oResult[0], 'Placement'));
        $this->assertEqual($oResult[0]->id, 1);
        $this->assertEqual($oResult[0]->expire, '2005-12-08 13:55:00');
        $this->assertEqual($oResult[0]->targetImpressions, 10);
        $this->assertEqual($oResult[0]->targetClicks, 20);
        $this->assertEqual($oResult[0]->targetConversions, 30);
        $this->assertEqual($oResult[0]->dailyTargetImpressions, 5);
        $this->assertEqual($oResult[0]->dailyTargetClicks, 6);
        $this->assertEqual($oResult[0]->dailyTargetConversions, 7);
        $this->assertEqual($oResult[0]->priority, 3);
        $this->assertTrue(is_a($oResult[1], 'Placement'));
        $this->assertEqual($oResult[1]->id, 2);
        $this->assertEqual($oResult[1]->expire, '2005-12-08 13:55:01');
        $this->assertEqual($oResult[1]->targetImpressions, 11);
        $this->assertEqual($oResult[1]->targetClicks, 21);
        $this->assertEqual($oResult[1]->targetConversions, 31);
        $this->assertEqual($oResult[1]->dailyTargetImpressions, 6);
        $this->assertEqual($oResult[1]->dailyTargetClicks, 7);
        $this->assertEqual($oResult[1]->dailyTargetConversions, 8);
        $this->assertEqual($oResult[1]->priority, 4);
    }

    /**
     * A method to test the getValidPlacements() method.
     *
     * Requirements:
     * Test 1: Sets the "current" time in the ServiceLocator, and then
     *         uses a the mocked DAL class to ensure that the
     *         getValidPlacements() method forms the correct "where"
     *         statements, and that these are passed in via the
     *         getAllPlacements() method.
     */
    function testGetValidPlacements()
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        $table = $conf['table']['prefix'] . $conf['table']['campaigns'];
        $oGetRequiredImpressionsType1 = &$this->_getCurrentTask();

        // Test 1
        $oServiceLocator = &ServiceLocator::instance();
        $oDate = &new Date('2005-12-08 13:55:00');
        $oServiceLocator->register('now', $oDate);
        $oGetRequiredImpressionsType1->oDal->setReturnValue('getPlacements', array());
        $oGetRequiredImpressionsType1->oDal->expectOnce(
            'getPlacements',
            array(
                array(),
                array(
                    array("($table.activate = '0000-00-00' OR $table.activate <= '" . $oDate->format('%Y-%m-%d') . "')", 'AND'),
                    array("$table.expire >= '" . $oDate->format('%Y-%m-%d') . "'", 'AND'),
                    array("$table.priority >= 1", 'AND'),
                    array("$table.active = 't'", 'AND'),
                    array("($table.views > 0 OR $table.clicks > 0 OR $table.conversions > 0)", 'AND')
                )
            )
        );
        $oResult = $oGetRequiredImpressionsType1->getValidPlacements();
        $this->assertTrue(is_array($oResult));
        $this->assertEqual(count($oResult), 0);
    }

    /**
     * A method to test the getInventoryImpressionsRequired() method.
     *
     * Requirements:
     * Test 1: Test with no inventory required, and ensure that 0 is returned.
     * Test 2: Test with inventory required, but no past data, and ensure that
     *         the default ratio is used correctly.
     * Test 3: Test with inventory required, but no past data, and ensure that
     *         the default ratio is used correctly, and that values are rounded
     *         up.
     * Test 4: Test with past data, and ensure that real ratio is calculated
     *         and used correctly.
     */
    function testGetInventoryImpressionsRequired()
    {
        $oGetRequiredImpressionsType1 = &$this->_getCurrentTask();

        // Test 1
        $inventory = 0;
        $defaultRatio = 0.1;
        $result = $oGetRequiredImpressionsType1->getInventoryImpressionsRequired($inventory, $defaultRatio);
        $this->assertEqual($result, 0);

        // Test 2
        $inventory = 1;
        $defaultRatio = 0.1;
        $result = $oGetRequiredImpressionsType1->getInventoryImpressionsRequired($inventory, $defaultRatio);
        $this->assertEqual($result, 10);

        // Test 3
        $inventory = 1;
        $defaultRatio = 0.3;
        $result = $oGetRequiredImpressionsType1->getInventoryImpressionsRequired($inventory, $defaultRatio);
        $this->assertEqual($result, 4);

        // Test 4
        $inventory = 1;
        $defaultRatio = 0.3;
        $inventoryToDate = 100;
        $impressionsToDate = 100000;
        $result = $oGetRequiredImpressionsType1->getInventoryImpressionsRequired(
            $inventory,
            $defaultRatio,
            $inventoryToDate,
            $impressionsToDate
        );
        $this->assertEqual($result, 1000);
    }

    /**
     * A method to test the getSmallestNonZeroInteger() method.
     */
    function testGetSmallestNonZeroInteger()
    {
        $oGetRequiredImpressionsType1 = &$this->_getCurrentTask();
        $this->assertEqual(0, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger(array(0,0,0)));
        $this->assertEqual(1, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger(array(1,0,0)));
        $this->assertEqual(1, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger(array(-1,1,1)));
        $this->assertEqual(1, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger(array(1,1,1)));
        $this->assertEqual(0, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger(array(-1,-1,-1)));
        $this->assertEqual(4, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger(array(32,18,4)));
        $this->assertEqual(0, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger(array(-1,'what','string')));
        $this->assertEqual(0, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger('foo'));
        $this->assertEqual(0, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger(5000));
        $this->assertEqual(0, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger());
        $this->assertEqual(748, $oGetRequiredImpressionsType1->getSmallestNonZeroInteger(array(748,849,35625)));
    }

    /**
     * A method to test the getPlacementImpressionInventoryRequirement() method.
     */
    function testGetPlacementImpressionInventoryRequirement()
    {
        // Generate a partial mock of the Placement class, and override
        // the setSummaryStatisticsToDate() method, so that it doesn't
        // actually call the DAL when the
        // getPlacementImpressionInventoryRequirement() is called
        Mock::generatePartial(
            'Placement',
            'PlacementInventoryRequirement',
            array('setSummaryStatisticsToDate')
        );
        $oPlacement = &new PlacementInventoryRequirement($this);

        // Manually set the remaining inventory that would normally be
        // set by the mocked setSummaryStatisticsToDate() method above
        $oPlacement->sumImpressions = 10000;
        $oPlacement->sumClicks      = 100;
        $oPlacement->sumConversions = 10;

        // Set the target impressions, clicks and conversions
        $oPlacement->targetClicks      = 10;
        $oPlacement->targetConversions = 0;

        // Test the method
        $oGetRequiredImpressionsType1 = $this->_getCurrentTask();
        $oGetRequiredImpressionsType1->getPlacementImpressionInventoryRequirement($oPlacement);
        $this->assertEqual(1000, $oPlacement->requiredImpressions);
    }

    /**
     * A method to test the getPlacementAdWeightTotal() method.
     */
    function testGetPlacementAdWeightTotal()
    {
        // Create a test Placement object with no Adverts
        $oPlacement = &new Placement();
        $oPlacement->Placement();
        // Test the resutned sum is unity
        $oGetRequiredImpressionsType1 = &$this->_getCurrentTask();
        $this->assertEqual(1, $oGetRequiredImpressionsType1->getPlacementAdWeightTotal($oPlacement));

        // Create some test Advert objects
        $oAdvert1 = new Advert(array('ad_id' => 1, 'active' => true, 'weight' => 2));
        $oAdvert2 = new Advert(array('ad_id' => 2, 'active' => true, 'weight' => 1));
        $oAdvert3 = new Advert(array('ad_id' => 3, 'active' => true, 'weight' => 0));
        $oAdvert4 = new Advert(array('ad_id' => 4, 'active' => true, 'weight' => 3));
        $oAdvert5 = new Advert(array('ad_id' => 5, 'active' => true, 'weight' => -10));
        $oAdvert6 = new Advert(array('ad_id' => 6, 'active' => false, 'weight' => 100));
        // Create a test Placement object
        $oPlacement = &new Placement();
        $oPlacement->Placement();
        // Add the Adverts to the Placement
        $oPlacement->adverts[] = $oAdvert1;
        $oPlacement->adverts[] = $oAdvert2;
        $oPlacement->adverts[] = $oAdvert3;
        $oPlacement->adverts[] = $oAdvert4;
        $oPlacement->adverts[] = $oAdvert5;
        $oPlacement->adverts[] = $oAdvert6;
        // Test the returned sum is correct
        $normal = &$this->_getCurrentTask();
        $this->assertEqual(6, $oGetRequiredImpressionsType1->getPlacementAdWeightTotal($oPlacement));
    }

    /**
     * A method to test the distributePlacementImpressions() method.
     */
    function testDistributePlacementImpressions()
    {
        $oGetRequiredImpressionsType1 = &$this->_getCurrentTask();
        $aPlacements = array();

        // Set the current date/time
        $oServiceLocator = &ServiceLocator::instance();
        $oServiceLocator->remove('now');
        $oDate = &new Date('2005-12-09 12:00:01');
        $oServiceLocator->register('now', $oDate);

        // Create a "normal" placement to test with
        $oPlacement = &new Placement(array('campaignid' => 1, 'expire' => '2005-12-09'));
        $oPlacement->requiredImpressions = 24;
        $oAdvert = &new Advert(array('ad_id' => 1, 'weight' => 1, 'active' => 't'));
        $oPlacement->adverts[] = $oAdvert;
        $oAdvert = &new Advert(array('ad_id' => 2, 'weight' => 1, 'active' => 't'));
        $oPlacement->adverts[] = $oAdvert;
        $oAdvert = &new Advert(array('ad_id' => 3, 'weight' => 1, 'active' => 'f'));
        $oPlacement->adverts[] = $oAdvert;
        $aPlacements[] = $oPlacement;

        // Create a "daily limit" placement to test with
        $oPlacement = &new Placement(array('campaignid' => 2, 'expire' => '0000-00-00'));
        $oPlacement->dailyTargetImpressions = 24;
        $oPlacement->requiredImpressions = 24;
        $oAdvert = &new Advert(array('ad_id' => 4, 'weight' => 1, 'active' => 't'));
        $oPlacement->adverts[] = $oAdvert;
        $oAdvert = &new Advert(array('ad_id' => 5, 'weight' => 1, 'active' => 'f'));
        $oPlacement->adverts[] = $oAdvert;
        $aPlacements[] = $oPlacement;

        // Set the DAL saveRequiredAdImpressions() method to expect the
        // desired input from the distributePlacementImpressions() method.
        $oGetRequiredImpressionsType1->oDal->expectOnce(
            'saveRequiredAdImpressions',
            array(
                array(
                    array(
                        'ad_id'                => 1,
                        'required_impressions' => (double) 1
                    ),
                    array(
                        'ad_id'                => 2,
                        'required_impressions' => (double) 1
                    ),
                    array(
                        'ad_id'                => 4,
                        'required_impressions' => (double) 2
                    )
                )
            )
        );

        // Test
        $oGetRequiredImpressionsType1->distributePlacementImpressions($aPlacements);
    }

}

?>
