<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: PriorityDeliveryLimitationDate.mtp.test.php 4131 2006-01-26 18:08:38Z andrew@m3.net $
*/

require_once MAX_PATH . '/lib/max/Maintenance/Priority/DeliveryLimitation.php';
require_once MAX_PATH . '/lib/max/Maintenance/Priority/DeliveryLimitation/Date.php';
require_once 'Date.php';

/**
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     James Floyd <james@m3.net>
 */
class Delivery_TestOfPriorityDeliveryLimitationDate extends UnitTestCase
{

   /**
    * The constructor method.
    */
    function Delivery_TestOfPriorityDeliveryLimitationDate()
    {
        $this->UnitTestCase();
    }

   /**
    * Test 1 - Test date == delivery requirement
    * Test 2 - Test date != delivery requirement
    * Test 3 - Test date <= delivery requirement
    * Test 4 - Test date >= delivery requirement
    * Test 5 - Test date <  delivery requirement
    * Test 6 - Test date >  delivery requirement
    * Test 7 - Bad input, no date object passed to method
    */
    function testTestInterval()
    {

        // Test 1 - test date == delivery requirement
        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '==',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test for same date interval as delivery allowed
        $date = new Date('2005-04-03');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // false = ad is active for this interval
        $this->assertFalse($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '==',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test interval one day after active date
        $date = new Date('2005-04-04');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // True = ad is inactive in this interval
        $this->assertTrue($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '==',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test interval one day beore active date
        $date = new Date('2005-04-02');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // True = ad is inactive in this interval
        $this->assertTrue($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        // Test 2 -  Test != delivery requirement
        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '!=',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test same interval
        $date = new Date('2005-04-03');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // True = ad is inactive in this interval
        $this->assertTrue($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '!=',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test interval one day after active date
        $date = new Date('2005-04-04');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // False = ad is active in this interval
        $this->assertFalse($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '!=',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test interval one day beore active date
        $date = new Date('2005-04-02');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // False = ad is active in this interval
        $this->assertFalse($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        // Test 3
        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '<=',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test same date interval limitation
        $date = new Date('2005-04-03');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // False = ad is active in this interval
        $this->assertFalse($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '<=',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test year before date interval limitation
        $date = new Date('2004-04-03');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // False = ad is active in this interval
        $this->assertFalse($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '<=',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test one day after date interval limitation
        $date = new Date('2005-04-04');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // True = ad is inactive in this interval
        $this->assertTrue($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        // Test 4
        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '>=',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test same day date interval limitation
        $date = new Date('2005-04-03');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // False = ad is active in this interval
        $this->assertFalse($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '>=',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test date interval before limitation
        $date = new Date('2005-04-02');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // True = ad is inactive in this interval
        $this->assertTrue($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);

        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '>=',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test date interval after limitation
        $date = new Date('2005-04-02');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // True = ad is inactive in this interval
        $this->assertTrue($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        // Test 5
        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '<',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test date interval before limitation date
        $date = new Date('2005-04-02');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // False = ad is active in this interval
        $this->assertFalse($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '<',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test same date interval as limitation
        $date = new Date('2005-04-03');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // True = ad is inactive in this interval
        $this->assertTrue($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '<',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test date after limitation date
        $date = new Date('2005-04-04');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // True = ad is inactive in this interval
        $this->assertTrue($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        // Test 6
        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '>',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test date interval before limitation date
        $date = new Date('2005-04-02');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // True = ad is inactive in this interval
        $this->assertTrue($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '>',
            'data' => '2005-04-03',
            'executionorder' => 1,
        );
        // test same date interval as limitation
        $date = new Date('2005-04-03');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // True = ad is inactive in this interval
        $this->assertTrue($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);


        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '>',
            'data' => '20050403',
            'executionorder' => 1,
        );
        // test date after limitation date
        $date = new Date('2005-04-04');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // False = ad is active in this interval
        $this->assertFalse($oLimitationDate->testInterval($date));
        unset($aLimitation, $date, $oLimitationDate);

        // Test 7
        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Date',
            'comparison' => '>',
            'data' => '20050403',
            'executionorder' => 1,
        );
        // test date after limitation date
        $date = new Date('2005-04-04');
        $oLimitationDate = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        // False = ad is active in this interval
        PEAR::pushErrorHandling(null);
        $this->assertTrue(is_a($oLimitationDate->testInterval('not a date ;)'), 'pear_error'));
        PEAR::popErrorHandling();
        unset($aLimitation, $date, $oLimitationDate);
    }

   /**
    * Test if method returns expected time period
    */
    function testMinutesPerTimePeriod()
    {
        $this->assertEqual(MAX_Maintenance_Priority_DeliveryLimitation_Date::minutesPerTimePeriod(), 1440);
    }
}

?>
