<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: PriorityDeliveryLimitationDay.mtp.test.php 4131 2006-01-26 18:08:38Z andrew@m3.net $
*/

require_once MAX_PATH . '/lib/max/Maintenance/Priority/DeliveryLimitation.php';
require_once MAX_PATH . '/lib/max/Maintenance/Priority/DeliveryLimitation/Day.php';
require_once 'Date.php';

/**
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     James Floyd <james@m3.net>
 */
class Delivery_TestOfPriorityDeliveryLimitationDay extends UnitTestCase
{
   /**
    * The constructor method.
    */
    function Delivery_TestOfPriorityDeliveryLimitationDay()
    {
        $this->UnitTestCase();
    }

    function testCalculateNonDeliveryDeliveryLimitation()
    {
        // Test 1 - test non delivery restrictions are being set
        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Day',
            'comparison' => '==',
            'data' => '0,2,5',
            'executionorder' => 1,
        );
        $days = range(0,6);
        unset($days[0], $days[2], $days[5]);
        $oLimitationDay = & MAX_Maintenance_Priority_DeliveryLimitation::factory($aLimitation);
        $oLimitationDay->calculateNonDeliveryDeliveryLimitation();
        $this->assertTrue(count($oLimitationDay->data) == 4);
        $this->assertTrue($oLimitationDay->data == $days);
        unset($aLimitation, $oLimitationDay, $days);
    }

    function testMinutesPerTimePeriod()
    {
       $aDeliveryLimitation = array(
            'ad_id' => 3,
            'logical' => 'and',
            'type' => 'Time:Day',
            'comparison' => '==',
            'data' => '0,6',
            'executionorder' => 0
       );
       $obj = &$this->getInstance($aDeliveryLimitation);
       $this->assertEqual(10080, $obj->minutesPerTimePeriod());
    }

    function testTestInterval()
    {
        Mock::generatePartial('MAX_Maintenance_Priority_DeliveryLimitation_Day', $mockClass = 'MAX_Maintenance_Priority_DeliveryLimitation_Day' . rand(),
            array('calculateNonDeliveryRestrictions'));
        $obj =& new $mockClass($this);

        $obj->setReturnValue('calculateNonDeliveryRestrictions', true);

        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'Time:Day',
            'comparison' => '==',
            'data' => '1, 5, 4, 6',
            'executionorder' => 1,
        );
        $aData = range(0,6);
        unset($aData[1], $aData[5], $aData[4], $aData[6]);
        $obj->MAX_Maintenance_Priority_DeliveryLimitation_Day($aLimitation);

        // set fake delivery restrictions that should be set by calculateNonDeliveryRestrictions()
        $obj->data = $aData;

        $oTestStartDate = new Date('2005-05-15 00:00:00');

        foreach (range(0,6) as $key => $hour) {
            if (in_array($key, $aData)) {
                $this->assertTrue($obj->testInterval($oTestStartDate) == true);
            } else {
                $this->assertTrue($obj->testInterval($oTestStartDate) == false);
            }
            // move test date on by one day
            $oTestStartDate->addSeconds(SECONDS_PER_DAY);
        }
    }

    function &getInstance($aDeliveryLimitation)
    {
        return new MAX_Maintenance_Priority_DeliveryLimitation_Day($aDeliveryLimitation);
    }
}

?>
