<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: adview.plugin.php 3745 2005-10-11 16:44:51Z arlen $
*/

/**
 * @package    Plugins
 * @subpackage DeliveryLimitations
 * @author     Chris Nutting <chris@m3.net>
 *
 */

require_once MAX_PATH . '/plugins/deliveryLimitations/DeliveryLimitations.php';
require_once MAX_PATH . '/lib/max/Plugins/PluginTranslation.php';

/**
 *
 * Netspeed delivery limitation plugin.
 *
 */
class Plugins_DeliveryLimitations_Geo_City extends Plugins_DeliveryLimitations  
{
    
    /**
     * Return name of plugin
     *
     * @return string
     */
    function getName()
    {
        return Max_PluginTranslation::translate('Country / City', $this->module, $this->package);
    }
    
    /**
     * Return if this plugin is available in the current context
     *
     * @return boolean
     */
    function isAllowed()
    {
        if ((isset($GLOBALS['_MAX']['GEO_DATA']['city'])) || $GLOBALS['_MAX']['CONF']['geotargeting']['showUnavailable']) {
            return true;
        } else {
            return false;
        }
    }
    
    /**
     * Outputs the HTML to display the data for this limitation
     *
     * @return void
     */
    function displayData()
    {
        $tabindex =& $GLOBALS['tabindex'];


        // The city plugin is slightly different since we need to allow for multiple city names in different countries
        echo "
            <table border='0' cellpadding='2'>
                <tr>
                    <th>" . Max_PluginTranslation::translate('Country', $this->module, $this->package) . "</th>
                    <td>
                        <select name='acl[{$this->executionorder}][data][]' {$disabled}>";
                        foreach ($this->res as $countryCode => $countryName) {
                            $selected = ($this->data[0] == $countryCode) ? 'selected="selected"' : '';
                            echo "<option value='{$countryCode}' {$selected}>{$countryName}</option>";
                        }
                        echo "
                        </select>
                    &nbsp;<input type='image' name='action[none]' src='images/{$GLOBALS['phpAds_TextDirection']}/go_blue.gif' border='0' align='absmiddle' alt='{$GLOBALS['strSave']}'></td>
                </tr>";
        
        if (!empty($this->data[0])) {
            // A country has been selected, show city list for this country...
            // Note: Since a disabled field does not pass it's value through, we need to pass the selected country in...
            echo "<tr><th>" . Max_PluginTranslation::translate('City(s)', $this->module, $this->package) . "</th><td>";
            echo "<input type='text' name='acl[{$this->executionorder}][data][]' value='{$this->data[1]}' tabindex='".($tabindex++)."' />";
            echo "</td></tr>";
        }
        echo "
            </table>
        ";
    }
    
    /**
     * If $this->data should be an array, this method loads the saved string into an array
     *
     * @return string
     */
    function loadData()
    {
        if (!is_array($this->data)) {
            $this->data = strlen($this->data) ? explode('|', $this->data) : array();
        }
        return true;
    }
        
    /**
     * Returns the data for this limitation
     *
     * @return string
     */
    function saveData()
    {
        return implode('|', $this->data);
    }
    
    /**
     * Returns the compiledlimitation string for this limitation
     *
     * @return string
     */
    function compile()
    {
        $cities = explode(',', $this->data[1]);
        foreach ($cities as $city) {
            $trimmedCities[] = trim(strtolower($city));
        }
        $data = $this->data[0] . '|' . implode(',', $trimmedCities);
        return 'MAX_check' . ucfirst($this->package) . '_' . $this->name . "(\'{$data}\', \'{$this->comparison}\')";
    }
}

?>
