<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: adview.plugin.php 3745 2005-10-11 16:44:51Z arlen $
*/

/**
 * @package    Plugins
 * @subpackage DeliveryLimitations
 * @author     Chris Nutting <chris@m3.net>
 *
 */

require_once MAX_PATH . '/plugins/deliveryLimitations/DeliveryLimitations.php';
require_once MAX_PATH . '/lib/max/Plugins/PluginTranslation.php';

/**
 *
 * Netspeed delivery limitation plugin.
 *
 */
class Plugins_DeliveryLimitations_Geo_Region extends Plugins_DeliveryLimitations  
{
    
    /**
     * Return name of plugin
     *
     * @return string
     */
    function getName()
    {
        return Max_PluginTranslation::translate('Country / Region', $this->module, $this->package);
    }
    
    /**
     * Return if this plugin is available in the current context
     *
     * @return boolean
     */
    function isAllowed()
    {
        if ((isset($GLOBALS['_MAX']['GEO_DATA']['region'])) || $GLOBALS['_MAX']['CONF']['geotargeting']['showUnavailable']) {
            return true;
        } else {
            return false;
        }
    }
    
    /**
     * Outputs the HTML to display the data for this limitation
     *
     * @return void
     */
    function displayData()
    {
        $tabindex =& $GLOBALS['tabindex'];

        // The region plugin is slightly different since we need to allow for multiple regions in different countries
        echo "
            <table border='0' cellpadding='2'>
                <tr>
                    <th>" . Max_PluginTranslation::translate('Country', $this->module, $this->package) . "</th>
                    <td>
                        <select name='acl[{$this->executionorder}][data][]' {$disabled}>";
                        foreach ($this->res as $countryCode => $countryName) {
                            if (count($countryName) === 1) { continue; }
                            $selected = ($this->data[0] == $countryCode) ? 'selected="selected"' : '';
                            echo "<option value='{$countryCode}' {$selected}>{$countryName[0]}</option>";
                        }
                        echo "
                        </select>
                    &nbsp;<input type='image' name='action[none]' src='images/{$GLOBALS['phpAds_TextDirection']}/go_blue.gif' border='0' align='absmiddle' alt='{$GLOBALS['strSave']}'></td>
                </tr>";
        
        if (!empty($this->data[0])) {
            // A country has been selected, show city list for this country...
            // Note: Since a disabled field does not pass it's value through, we need to pass the selected country in...
            echo "<tr><th>" . Max_PluginTranslation::translate('Region(s)', $this->module, $this->package) . "</th><td><div class='box'>";
            $aRegions = $this->res[$this->data[0]];
            unset($aRegions[0]);
            $aSelectedRegions = $this->data;
            unset ($aSelectedRegions[0]);
            foreach ($aRegions as $sCode => $sName) {
                echo "<div class='boxrow' onMouseOver='boxrow_over(this);' onMouseOut='boxrow_leave(this);' onClick='o=findObj(\"c_{$this->executionorder}_{$sCode}\"); o.checked = !o.checked;'>";
                echo "<input onClick='boxrow_nonbubble();' tabindex='".($tabindex++)."' ";
                echo "type='checkbox' id='c_{$this->executionorder}_{$sCode}' name='acl[{$this->executionorder}][data][]' value='{$sCode}'".(in_array($sCode, $aSelectedRegions) ? ' CHECKED' : '').">{$sName}</div>";
            }
            echo "</div></td></tr>";
        }
        echo "
            </table>
        ";
    }
    
    /**
     * If $this->data should be an array, this method loads the saved string into an array
     *
     * @return string
     */
    function loadData()
    {
        if (!is_array($this->data)) {
            $aCountry = strlen($this->data) ? explode('|', $this->data) : array();
            $aRegions = strlen($aCountry[1]) ? explode(',', $aCountry[1]) : array();
            $this->data = array_merge(array($aCountry[0]), $aRegions);
        }
        return true;
    }
        
    /**
     * Returns the data for this limitation
     *
     * @return string
     */
    function saveData()
    {
        $data = $this->data;
        $country = $data[0];
        unset($data[0]);
        
        return $country . '|' . implode(',', $data);
    }
}

?>
